@@ -100,6 +100,7 @@ typedef perl_libpng_t * Image__PNG__Libpng;
         return &PL_sv_undef;                    \
     }
 
+//#define PERL_PNG_MESSAGES
 #undef PERL_PNG_MESSAGES
 
 /* Send a message. */
@@ -545,12 +546,21 @@ perl_png_set_text_from_hash (perl_libpng_t * png,
     unsigned int text_length;
     /* The return value of this function. */
     int ok = 1;
+    SV ** compression_sv_ptr;
 
     MESSAGE ("Putting it into something.");
 
     /* Check the compression field of the chunk */
 
-    HASH_FETCH_IV (chunk, compression);
+    compression_sv_ptr =
+	hv_fetch (chunk, "compression", strlen ("compression"), 0);
+    if (compression_sv_ptr) {
+	compression = SvIV (* compression_sv_ptr);
+    }
+    else {
+	MESSAGE ("Using default compression PNG_TEXT_COMPRESSION_NONE");
+	compression = PNG_TEXT_COMPRESSION_NONE;
+    }
     switch (compression) {
     case PNG_TEXT_COMPRESSION_NONE:
         break;
@@ -1655,9 +1665,9 @@ static SV * perl_png_get_valid (perl_libpng_t * png)
     valid = png_get_valid (pngi, 0xFFFFFFFF);
 #define V(x) \
     (void) hv_store (perl_valid, #x, strlen (#x), newSViv (valid & PNG_INFO_ ## x), 0)
-#line 1658 "perl-libpng.c"
+#line 1668 "perl-libpng.c"
 V(bKGD);V(cHRM);V(gAMA);V(hIST);V(iCCP);V(IDAT);V(oFFs);V(pCAL);V(pHYs);V(PLTE);V(sBIT);V(sCAL);V(sPLT);V(sRGB);V(tIME);V(tRNS);
-#line 1661 "perl-libpng.c.tmpl"
+#line 1671 "perl-libpng.c.tmpl"
 #undef V
 
     return newRV_inc ((SV *) perl_valid);
@@ -2033,7 +2043,7 @@ static void perl_png_set_unknown_chunks (perl_libpng_t * png, AV * chunk_list)
 
 int perl_png_libpng_supports (const char * what)
 {
-#line 2036 "perl-libpng.c"
+#line 2046 "perl-libpng.c"
     if (strcmp (what, "iTXt") == 0) {
 #ifdef PNG_iTXt_SUPPORTED
         return 1;
@@ -2076,7 +2086,7 @@ int perl_png_libpng_supports (const char * what)
         return 0;
 #endif /* iCCP */
     }
-#line 2047 "perl-libpng.c.tmpl"
+#line 2057 "perl-libpng.c.tmpl"
 
     /* sCAL is a special case. */
 
@@ -2193,7 +2203,7 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
 {
     if (VALID (cHRM)) {
         HV * ice;
-#line 2196 "perl-libpng.c"
+#line 2206 "perl-libpng.c"
         double white_x;
         double white_y;
         double red_x;
@@ -2202,10 +2212,10 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
         double green_y;
         double blue_x;
         double blue_y;
-#line 2168 "perl-libpng.c.tmpl"
+#line 2178 "perl-libpng.c.tmpl"
         png_get_cHRM (pngi , & white_x, & white_y, & red_x, & red_y, & green_x, & green_y, & blue_x, & blue_y);
         ice = newHV ();
-#line 2208 "perl-libpng.c"
+#line 2218 "perl-libpng.c"
         (void) hv_store (ice, "white_x", strlen ("white_x"),
                          newSVnv (white_x), 0);
         (void) hv_store (ice, "white_y", strlen ("white_y"),
@@ -2222,7 +2232,7 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
                          newSVnv (blue_x), 0);
         (void) hv_store (ice, "blue_y", strlen ("blue_y"),
                          newSVnv (blue_y), 0);
-#line 2177 "perl-libpng.c.tmpl"
+#line 2187 "perl-libpng.c.tmpl"
         return newRV_inc ((SV *) ice);
     }
     UNDEF;
@@ -2231,7 +2241,7 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
 static void perl_png_set_cHRM (perl_libpng_t * png, HV * cHRM)
 {
     SV ** key_sv_ptr;
-#line 2234 "perl-libpng.c"
+#line 2244 "perl-libpng.c"
     double white_x = 0.0;
     double white_y = 0.0;
     double red_x = 0.0;
@@ -2272,9 +2282,9 @@ static void perl_png_set_cHRM (perl_libpng_t * png, HV * cHRM)
     if (key_sv_ptr) {
         blue_y = SvNV (* key_sv_ptr);
     }
-#line 2196 "perl-libpng.c.tmpl"
+#line 2206 "perl-libpng.c.tmpl"
     png_set_cHRM (pngi, white_x, white_y, red_x, red_y, green_x, green_y, blue_x, blue_y);
-#line 2199 "perl-libpng.c.tmpl"
+#line 2209 "perl-libpng.c.tmpl"
 }
 
 static void perl_png_set_transforms (perl_libpng_t * png, int transforms)
